aboutsummaryrefslogtreecommitdiff
path: root/src/lua/modules/time/time.cpp
diff options
context:
space:
mode:
authorchai <chaifix@163.com>2018-10-23 12:23:58 +0800
committerchai <chaifix@163.com>2018-10-23 12:23:58 +0800
commit40fc27154fe754181934dc7ee31375e6bdfb33fc (patch)
tree897ad98d759bc308ef66561181ba88b85f2ccd47 /src/lua/modules/time/time.cpp
parent1480c9445100075c9e1a894eb07c0ef727b509a1 (diff)
*merge from minimal
Diffstat (limited to 'src/lua/modules/time/time.cpp')
-rw-r--r--src/lua/modules/time/time.cpp54
1 files changed, 27 insertions, 27 deletions
diff --git a/src/lua/modules/time/time.cpp b/src/lua/modules/time/time.cpp
index 39743b4..f6e6f26 100644
--- a/src/lua/modules/time/time.cpp
+++ b/src/lua/modules/time/time.cpp
@@ -2,37 +2,37 @@
#include <SDL2/SDL.h>
#include "libjin/jin.h"
-namespace jin
-{
-namespace lua
+namespace JinEngine
{
+ namespace Lua
+ {
- using namespace jin::time;
+ using namespace JinEngine::Time;
- static int l_sec(lua_State* L)
- {
- luax_pushnumber(L, getSecond());
- return 1;
- }
+ static int l_sec(lua_State* L)
+ {
+ luax_pushnumber(L, getSecond());
+ return 1;
+ }
- static int l_sleep(lua_State* L)
- {
- double sec = luax_checknumber(L, 1);
- sleep(sec * 1000.0f);
- return 0;
- }
+ static int l_sleep(lua_State* L)
+ {
+ double sec = luax_checknumber(L, 1);
+ sleep(sec * 1000.0f);
+ return 0;
+ }
- static const luaL_Reg f[] = {
- { "second", l_sec },
- { "sleep", l_sleep },
- { 0, 0 },
- };
+ static const luaL_Reg f[] = {
+ { "second", l_sec },
+ { "sleep", l_sleep },
+ { 0, 0 },
+ };
- int luaopen_time(lua_State* L)
- {
- luax_newlib(L, f);
- return 1;
- }
+ int luaopen_time(lua_State* L)
+ {
+ luax_newlib(L, f);
+ return 1;
+ }
-} // lua
-} // jin \ No newline at end of file
+ } // namespace Lua
+} // namespace JinEngine \ No newline at end of file